package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````U18``#0```"8@0````0`!30`(``)
M`"@`&P`:``$``'`T?```-'P``#1\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!`?```0'P```4`````$```
M`0```+A]``"XC0``N(T``)`"``"D`@``!@`````0```"````P'T``,"-``#`
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN'T`
M`+B-``"XC0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`9^\OBH2B:J"PU##S'NPICID63*($
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$P```!-````4```
M`%0```!5````7@```%\```!@`````````&(```!C````9````&4```!F````
M:0```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````#X$0````````,`"P```````)`````````#`!8`
M$`(`````````````$@```.0``````````````!(````!`P`````````````2
M````S`(`````````````$@```+X"`````````````!(```"6````````````
M```2````70$`````````````$@```/H``````````````!(````!````````
M```````@````MP(`````````````$@```"P"`````````````!(````K`0``
M```````````2````&P$`````````````$@```,4"`````````````!(````-
M`0`````````````2````U`$`````````````$@```!```````````````"``
M``![`0`````````````2````U`(`````````````$@```.D`````````````
M`!(```#W`0`````````````2````VP(`````````````$@```"P`````````
M`````"````#\`0`````````````2````1@``````````````$@```&,`````
M`````````!8```!-`0`````````````2````=@``````````````$@```-,`
M`````````````!(```"'```````````````2````Z@$`````````````$@``
M`-P!`````````````!(```#B`@`````````````2````ZP,`````````````
M$@```+<``````````````!(````1`P`````````````1````S0$`````````
M````$@```"L#`````````````!$````6`@`````````````2````"0(`````
M````````$@```#\!`````````````!(```#$`0`````````````2````B@(`
M````````````$@```+T!`````````````!(```#N```````````````2````
MJP$`````````````$@```'0!`````````````!(```"5`0`````````````2
M````:@(`````````````$@```.,!`````````````!(```#Q`0``````````
M```2````&0,`````````````$@```*(``````````````!(````E`@``````
M```````2````:`$`````````````$@```#T"`````````````!(````/`P``
M```````````1````F@(`````````````$0```,8``````````````!$```"S
M`0`````````````2````A@$`````````````$0```$X"`````````````!(`
M```'`P`````````````2````-`$`````````````$@```%P"````````````
M`!(```!&`@`````````````2````5```````````````$@```'@"````````
M`````!(```"A`@`````````````2````Z0(`````````````$@```*8!````
M`````````!(```#P`@`````````````2````J`(`````````````(@```$8$
M``!<D````````!``%P#T`P``.2T``,`````2``T`:P0``&TF``#X!```$@`-
M`(4"```)%0``S`$``!(`#0!K`P``51T```0````2``T`B0,``&4K``#4`0``
M$@`-`!P$``!(D````````!``%P"1!```61T``*`!```2``T`400``$B0````
M````$``7`'P#``#Y'@``&````!(`#0"?`P``N2,``&`````2``T```0``$`Z
M```$````$0`/`"H$``"1.```V````!(`#0`U!```;1P``#P````2``T`/00`
M`%R0````````$``7`&8$``!<D````````!``%P!_!```C24``.`````2``T`
MJ`0``!DD``!(````$@`-``\$````D````````!``%@##`P``$1\```P!```2
M``T`>`0``$B0````````$``6`)X$``!$D```!````!$`%@`5!```U18`````
M```2``T`700``!TX``!T````$@`-`!$$````D````````"``%@#9`P``?24`
M`!`````2``T`K0,``*D<``"L````$@`-`,\#``!I.0``O@```!(`#0!%!```
M7)`````````0`!<`L`0``!T@``"<`P``$@`-``!?7V=M;VY?<W1A<G1?7P!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!,7V-U<G)E
M;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`%]?<W1A8VM?8VAK7V9A:6P`
M97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T
M`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!?7VUE
M;6-P>5]C:&L`<W1R<W1R`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?
M7VQS=&%T-C1?=&EM938T`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H
M:P!?7VUE;6UO=F5?8VAK`%]?9G!R:6YT9E]C:&L`7U]L:6)C7W-T87)T7VUA
M:6X`7U]S=&%T-C1?=&EM938T`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI
M>F4`<W1R8VAR`&UE;6-M<`!M96US970`;W!E;F1I<@!G971U:60`86-C97-S
M`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!A8F]R=`!S=')N8VUP
M`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R
M9`!L:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O
M+C,`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S
M<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I
M<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A
M<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS
M-``````````"``$``@`"``(``0`!``$``0`"``,``0`!``(``0`"``$``0`"
M``(``@`"``$``@`!``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"``$`
M`@`#``(``0`"``(``@`"``(``@`"``$``@`!``(``@`"``$``@`!``(``@`!
M``(``@`!``,``@`"``(``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`!`%<#```0
M````(````!1I:0T```0`O00````````!``(`30,``!``````````M)&6!@``
M`P#'!```$````!1I:0T```(`O00```````"XC0``%P```+R-```7````_(\`
M`!<````$D```%P```!20```7````&)```!<````@D```%P```"20```7````
M*)```!<````LD```%P```#"0```7````.)```!<````\D```%P```$20```7
M````R(\``!4*``#,CP``%0L``-"/```5$P``U(\``!49``#8CP``$QP``-R/
M```5'0``X(\``!4>``#DCP``%28``.B/```5*```[(\``!4\``#PCP``%3T`
M`/2/```5/P``^(\``!5+``#4C@``%@,``-B.```6!```W(X``!8%``#@C@``
M%@8``.2.```6!P``Z(X``!8(``#LC@``%@D``/".```6"P``](X``!8,``#X
MC@``%@T``/R.```6#@```(\``!8/```$CP``%A````B/```6$0``#(\``!82
M```0CP``%A0``!2/```6%0``&(\``!86```<CP``%A<``""/```6&```)(\`
M`!8:```HCP``%AL``"R/```6'P``,(\``!8@```TCP``%B$``#B/```6(@``
M/(\``!8C``!`CP``%B0``$2/```6)0``2(\``!8G``!,CP``%BD``%"/```6
M*@``5(\``!8K``!8CP``%BP``%R/```6+0``8(\``!8N``!DCP``%B\``&B/
M```6,```;(\``!8Q``!PCP``%C(``'2/```6,P``>(\``!8T``!\CP``%C4`
M`("/```6-@``A(\``!8W``"(CP``%C@``(R/```6.0``D(\``!8Z``"4CP``
M%CX``)B/```60```G(\``!9!``"@CP``%D(``*2/```60P``J(\``!9$``"L
MCP``%D4``+"/```61@``M(\``!9'``"XCP``%D@``+R/```620``P(\``!9*
M``#$CP``%DL```A`+>E!`0#K"("]Z`3@+>4$X)_E#N"/X`CPON6T?````,:/
MX@?*C.*T_+SE`,:/X@?*C.*L_+SE`,:/X@?*C.*D_+SE`,:/X@?*C.*<_+SE
M`,:/X@?*C.*4_+SE`,:/X@?*C.*,_+SE`,:/X@?*C.*$_+SE`,:/X@?*C.)\
M_+SE`,:/X@?*C.)T_+SE`,:/X@?*C.)L_+SE`,:/X@?*C.)D_+SE`,:/X@?*
MC.)<_+SE`,:/X@?*C.)4_+SE`,:/X@?*C.),_+SE`,:/X@?*C.)$_+SE`,:/
MX@?*C.(\_+SE`,:/X@?*C.(T_+SE>$?]YP#&C^('RHSB*/R\Y0#&C^('RHSB
M(/R\Y0#&C^('RHSB&/R\Y0#&C^('RHSB$/R\Y0#&C^('RHSB"/R\Y0#&C^('
MRHSB`/R\Y0#&C^('RHSB^/N\Y0#&C^('RHSB\/N\Y0#&C^('RHSBZ/N\Y0#&
MC^('RHSBX/N\Y0#&C^('RHSBV/N\Y0#&C^('RHSBT/N\Y0#&C^('RHSBR/N\
MY0#&C^('RHSBP/N\Y0#&C^('RHSBN/N\Y0#&C^('RHSBL/N\Y0#&C^('RHSB
MJ/N\Y0#&C^('RHSBH/N\Y7A'_><`QH_B!\J,XI3[O.4`QH_B!\J,XHS[O.4`
MQH_B!\J,XH3[O.4`QH_B!\J,XGS[O.4`QH_B!\J,XG3[O.4`QH_B!\J,XFS[
MO.4`QH_B!\J,XF3[O.4`QH_B!\J,XES[O.5X1_WG`,:/X@?*C.)0^[SE`,:/
MX@?*C.)(^[SE`,:/X@?*C.)`^[SE`,:/X@?*C.(X^[SE`,:/X@?*C.(P^[SE
M`,:/X@?*C.(H^[SE`,:/X@?*C.(@^[SE`,:/X@?*C.(8^[SE>$?]YP#&C^('
MRHSB#/N\Y0#&C^('RHSB!/N\Y0#&C^('RHSB_/J\Y0#&C^('RHSB]/J\Y0#&
MC^('RHSB[/J\Y0#&C^('RHSBY/J\Y0#&C^('RHSBW/J\Y0#&C^('RHSBU/J\
MY0#&C^('RHSBS/J\Y0#&C^('RHSBQ/J\Y0````!PM5Y-BK!>2WU$7DS-Z080
M!JD%D@>H!:I\1.M8&V@)DT_P``/_]\#O5TI82Z)8`Y(11N-8!),81@+P<OI4
M2^-8'7@`+6/0'>YP+TI+!YA[1!MHQ1P$,+#Q@$_26)+XUC-#\`,#@OC6,W32
M@`#_]VKO2$E)2@-&>40&G'I$"6A08"!HF6!%20>:>4398$1)`2H88'E$66!E
MW2$=!.N"#@/Q#`Q1^`1+3/@$3XY%^='1'#Q,`"``D"I&?$1#^"$`.DG@:'E$
M__=([@`H,=`W30BN?43H:/_WWNX$1C5(,49X1`#P\OA`LS-+>T38:/_W%N[_
M]X[N,$HB2WI$TU@::`F;6D!/\``#,M$@1@JP<+W_]UKN*DIZ1-!@,+/_]X;N
M%DL=[G`O>T0;:--8@_B^5HSGX&C_]RKNR>>H:!"Q`?!X^]'G'T@Q1GA$`/"^
M^*A@`"C)T//G&TL<2'A$XU@#DQE&__?D[@0AH^<!(/_W-N__][[N`+]^>@``
MJ'D``+1Y```@`0``I'D````!```8`0``*`$``,)Z``#&>@``8"@``%(H``"(
M>@``,P8``'!Z``"N)0``6'H``,1X```L>@``XB0``"P!``#,)@``3_``"T_P
M``X"O&I&!+0!M-_X&*`%HYI$3_```PBT!$A:^```__?@[O_WF.W(=P``-`$`
M`!0PG^44()_E`S"/X`(@D^<``%+C'O\O`='^_^JP=P``!`$```9(!TL'2GA$
M>T1Z1(-"`]`%2]-8`[$81W!'`+\2>0``$'D``(YW```(`0``"$@)2WA$"4I[
M1!L:>D39#P'KHP%)$`/0!4O36`.Q&$=P1P"_Z'@``.1X``!@=P``#`$```BU
M"DL*2GM$>D0;>&NY"4O36".Q"$M[1!AH__>H[O_WO_\&2P$B>T0:<`B]LG@`
M`#!W```P`0``7G@``))X``#$YP"_+>GX0X!&'TM[1``H-M`>2IM8T_@`D+GQ
M``\QT`5X#T8`+1B_/2T4OP$E`"43T=GX`$!LL4Y&*D9!1B!&__<V[A"Y8UT]
M*Q#05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"`7AYZ;K"08!-2Q$
MMA`^8"!&O>CX@P1&Y^=,1N7G['8``!P!```72AA+>D00M01&GK#36&E&&V@=
MDT_P``/_]P;MH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH'9M:0$_P
M``,+T1ZP$+T`(/'G`B$@1O_W*.VP^H#P0`GIY__WG.UD=@``(`$``#1V```V
M2C=+>D3PM:&PTU@;:!^33_```Q"Q`W@$1ENY,4HP2WI$TU@::!^;6D!/\``#
M4]$AL/"]__>>[`5&`"CNT"A&__>L[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN
M*S+0($;_]PCM!T8P1O_W!.T'1`(W.$;_]U;M'$LZ1@(A>T0!E@"4!D;_]Y#M
M`JDP1O_W+NT!,#!&!=`&FP/T<$.S]8!/%]#_]^[L,$;_][KL*$;_]W;M`"C(
MT2A&__<2[2!&__=([:OG<W@N*\G1LW@`*[;0Q>?_]Y7_YN?_]RCM^'4``"`!
M``#<=0``C"$``%I*6TMZ1"WI\$\,1H.P!4;36-_X8($;:`&33_```PMX^$0]
M*PB_`30@1O_WKNQI1@9&*$;_]_+^@48`*%30__>D[(9"1]E,2P"?6/@#@+\`
M*W@`*QB_/2L4OP$C`",'T"M&$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WW.SP
M4>BQV/@`,"A&V5D0^`$["W`]*QB_`"L)T$H<$/@!.Q%&`O@!.P`K&+\]*_;1
M"D8](PMP%/@!.P+X`3\`*_G1+THL2WI$TU@::`&;6D!/\``#2M$#L+WH\(\)
M\?\Y%/@!.PGX`3\`*_G1Z><C2UCX`X#8^`!P.VB;LSM&4_@$+TE&"?$!"0`J
M^-$#,4_J@0L<2WM$&FC"N5A&`2(:8/_WC.R"1@`HR]`Y1D_JB0=;1CI&__?:
M[,CX`*#-^`"0"?$!"0`C2O@I,(3G648X1O_WTNR"1LCX````*+'03^J)!^OG
MF49/\`@+TN?_]VSL`+\,=0``(`$``/!T```<`0``4'0``(9U```MZ?!!#T8L
M22Q+K?6`77E$@K`&1@WU@%`$,`WQ!`C+6$#V_W)!1AMH`V!/\``#)$AX1/_W
M=NP$'@?=`JUC'@7K`PP<^`0LZKG;N1E+'>YP#SI&,49[1!MHP%C_]Y#K&4H-
M]8!1%4L$,7I$TU@::`MH6D!/\``#&-$-]8!=`K"]Z/"!'$8B1B\A0$;_]X+L
M`"C;T`A('>YP7R-&0D9X1`!H,48H6/_WQNO9Y__W".P`OTAT````=```?G,`
M`"`!``!P'P``)',``#"U'>YP3Q)*#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])
M`Y)Y1/_W,NP(20U+>40):`Q*>T1Z1&!8"TD!E7E$`)/_]W#K!;`PO<1S``"H
M<P``MG(``!0!``!T7P``QAX``+8A```M#P``R!X```I*@K`*21WN<,]Z1`9(
M"4MX1`!H4EA[1`=)7/@``'E$`9("L/_W^KM8<P``3G(``!0!```*7P``7AX`
M`"5*\+4E2WI$K?4`78>P#?4`40.LTU@4,0WU@%8;:`M@3_```__WN.L=2@(A
M'4L0-GI$S>D``GM$($9!\@$"__?$ZR!&3_2`4C%&__>RZP0>N+\`)0S;9QPX
M1O_W<NL%1C"Q.T8Q1B)&__?\Z@`C*U4-2@WU`%$)2Q0Q>D336!IH"VA:0$_P
M``,$T2A&#?4`70>P\+W_]UKK%G(``"`!``!0'@``/AX``*)Q``#_]ZB_6THM
MZ?!/!D9:2WI$K?6$78.P64@-]815#?$0"--8#$9X1$%&!#4;:"M@3_```__W
M(_TO(05&,$;_]W+JP+%/2#%&>$3_]PK^,$9-2@WUA%%(2P0Q>D336!IH"VA:
M0$_P``-`\(.`#?6$70.PO>CPCR!&__?\ZD-)>43_]QSK!$8`*-S0(W@-\8@*
MW_C\D*KQ!`?Y1``K2-`EL2%&*$;_]V[KN+,@1O_WGNI#'B-$@T:<0CZ_(Q@`
M(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]XKJ@T8P1O_WANI81`$PL/6`7ZS2
M*4@"(4M&3_2`4GA$`)3-Z0$&.$;_]P[K048X1O_WK.HPN5KX:#P#]'!#L_4`
M3Q?0'DD`('E$__?,Z@1&`"B,T"-X`"NVT=6Q*W@N*P30&$Q/\`$+?$3+YVMX
M`"OHT/;G`2$X1O_W+NH`*.'1$4@Y1GA$__>!_3A&__>&ZG/G#DQ/\`$+?$2S
MY__WENIB<0``(`$``+@=``"B'0``&'$``'P=``!F'0``$AT``-P<``"<'```
MD!P``&P<```0M2\A!$;_]^#I`+%$'"!&O>@00/_W6+H[2O"U.TMZ1*WU@%V#
ML`WU@%'36`0Q&V@+8$_P``,`*#S0`W@%1@`K.-#_]P#J0AP$1K+U@%]'V`&O
M*48X1O_W`NIC'CM$GT(+TC@9#?$%`@`A`N"00@%P`]`0^`$]+ROXT"\A.$;_
M]Z3I>+.X0H2_`",#<#A&__<>ZA]*#?6`41Q+!#%Z1--8&F@+:%I`3_```RO1
M#?6`70.P\+T72@WU@%$42P0Q>D336!IH"VA:0$_P``,:T1)(>$0-]8!=`["]
MZ/!`__?TN0`@UN<-2@WU@%$(2P0Q>D336!IH"VA:0$_P``,"T0A(>$3FY__W
M^NFN;P``(`$``#!O```.;P``9!L``-YN```T&P``S$K-2WI$<+7,3H*PS$W3
M6'Y$;$9]1!MH`9-/\``#(48P1O_WQ_NPL<9+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>Q^P`HZ-&\3GY$(48P1O_WJ?NPL;=+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>3^P`HZ-&N3GY$
M(48P1O_WB_NPL:A+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__=U^P`HZ-&@3GY$(48P1O_W;?NPL9E+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__=7^P`HZ-&23GY$(48P1O_W3_NPL8I+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<Y^P`HZ-&$3GY$
M(48P1O_W,?NPL7M+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__<;^P`HZ-%V3GY$(48P1O_W$_NPL6Q+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__?]^@`HZ-%H3GY$(48P1O_W]?JPL5U+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__??^@`HZ-%:3GY$
M(48P1O_WU_JPL4Y+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__?!^@`HZ-%,3GY$(48P1O_WN?JPL3]+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>C^@`HZ-$^3GY$(48P1O_WF_JPL3!+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>%^@`HZ-$P2"%&
M>$3_]W[Z`488L2U(>$3_]VK[+$@A1GA$__=S^@%&&+$J2'A$__=?^RE((49X
M1/_W:/H!1K"Q)DAX1/_W5/LE2A%+>D336!IH`9M:0$_P``,5T2%)(DAY1'A$
M`K"]Z'!`__=!NQ]((49X1/_W2OH!1@`HY-`<2'A$__<U^]_G__=2Z*1N```@
M`0``,!L``)1N```<`0``]!H``,`:``"0&@``7!H``#`:``"0&0``Q!D``)09
M``!D&0``K!@``/88``#2&```]!@``/P8``#^&```*A@``+1K``!<&@``7A@`
M`-(8``!<&```$TH42WI$`+432(.PTUAX1&E&&V@!DT_P``/_]_WY0+$`>``H
M&+\P*`R_`2``((#P`0`*2@=+>D336!IH`9M:0$_P``,"T0.P7?@$^_[W]N\(
M:P``(`$``-H7``#6:@``#[3?^#3``+4,2OQ$@[`$JPM)#$A<^`(@>402:`&2
M3_```E/X!"L`DPA8`B$`:/[WGN__(/_W2.BB:@``(`$``)1J```D`0``+>GP
M1P(A/TRM]8`]`"*&L'Q$#?6`-0`C%#6`1@"1.DEA6`EH*6!/\``!_O>H[P$X
M8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"!P`O2]M/\`@)P/(!"0.M`"$R
M1CM&0$8`D?[WBN^Q\?\_"+^P\?\_0=!*1BE&0$;^]PSO0QPVT`<H)MD(."P8
M(]+?^'R@^D0"X`$\K$(<TP@B448@1O[WHNX`*/719!N@&4?KY'$72@WU@#04
M2Q0T>D336!IH(VA:0$_P``,:T0WU@#T&L+WH\(>V]8`V9_$`![?Q_S\(OQ;U
M@#^XT4_P_S`!1M_G"$AX1/_W8/\'2'A$__=<__[W2.]4:@``(`$``!1K``"J
M:0``VA8``,(6```(M?[WK.[^]^[N`+$`:`B]+DHO2WI$\+4N3H>P!4;36'Y$
M!*DP1AMH!9-/\``#__<1^1"Q`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C
M2"E&>$0'L+WH\$#_]^VY*4;^]]CN6+$>2AE+>D336!IH!9M:0$_P``,FT0>P
M\+TH1O[WGNX'1B!&_O>:[@=$`C<X1O[W[.X32Q-).D9[1`*4>40`E0&1`B$$
M1O[W).\/2@=+>D336!IH!9M:0$_P``,$OR%&,$;%T/[WUNXT:0``(`$``)P6
M```*:0``:A8``-YH```X%0``,!4``)9H```MZ?!/W_AL),&PW_AL%'I$W_AH
M5'E$)J\(DGU$W_A@)`7Q#`,'D`7Q&`PLK#`U)D8-\:0)BE@-\2@($F@_DD_P
M``*3Z`<`A^@'`+SH#P`/QISH`P"&Z`,`E>@'`(GH!P#?^"`$049X1/_W?/@@
ML0-X!48`*T#P?H'^]_CM_O<Z[@`H`/"O@`9H`"X`\*N`,$;^]Q[N0@`"\0$*
M4$;^]V[N!48P>``H`/!W@=-&"97?^-B3^4121DM&`)`"(2A&`C7^]Z#NTT46
M^`$/6T8XOU-&H^L*`JKQ`@H",JKK`PJ:0BR_DD2:1``HY-'H2'A$`N!4^`0/
MB+%!1O_W-/@%1@`H]M`#>``K\]#_]W+X`"COT"A&_O<B[@1&B+E7^`1+=+$C
M>``K`/`0@2!&__=A^``H\]`@1O[W$.X$1@`H[=`@1O[WQNT)G09&*$;^]\+M
M!D0&\@1&,$;^]Q+NS4L'1C)&>T0"D\M+`B$#E7M$`9/*2P"4>T3^]T;N3_3@
M<3A&_O<6[0$P!='^]WSN`6@1*4#PXX!!1CA&_O=`[01&`"@\T+Y)")@'F[Y*
M0%@"(1MH>D0`EP!H_O?N[0`ENDJP2WI$TU@::#^;6D!/\``#0/!,@2A&0;"]
MZ/"/_O>^[09&`"A`\+2`6?@$"UBQ04;^][K_`"CWT`-X`"ONT5GX!`L`*//1
MJ4X-($_P#0O^][CM?D0%1@F0VD93($GG#IL#]'!#L_6`3[S1$)W^]R#MA4*W
MT0Z;P_,(`[/UX'^QT3!&_O>>[05&F4A!1GA$_O>+_P%&`"@`\*.`!YL8:/_W
M1_J#1@`H`/";@%A&_O<R[8%&`R@0V8])!#A81'E$_O?V[4BYN?$$#P#PV8#9
M1!GX!3PO*P#PTX"'2$%&>$3^]V/_(+$#>#`K&+\`*P;16$8`(?[W+NV`1@`H
M==%_28!(>43?^`"B>$3?^/R1__<^^-_X^('^]X#M?4M^2@(A>T3-Z0!S?$MZ
M1`*0*$8#DGM$,D;Z1/E$^$3^]X;M$^#^]\+M`V@1*Q71_O=F[0$TA$931C)&
M`B$H1LWI`TG-Z0&,`)?^]W+M3_3@<2A&_O=`[`$PY-`X1O[WI.QH2"E&>$3_
M]P3X*$;_]^W]..<<1OCF_O?`[$(``O$!"J#F4$H(F`>;@%@;:%Y*S>D`<0(A
M>D0`:/[W$NTAY__WU/U92D%+>D336!IH/YM:0$_P``-MT2A&0;"]Z/!/_O?>
MO`F5IN8'F]/X`+!@Y__W)OV!1K'Q``J#V[#Q"@)/\``+:O$``T!&S?@`L/[W
MUNPRJ08B0$8'D?[W7.P'F08H2=$RFD_TAD/$\D$SFD)_]&BOBHA$\DA3FD)_
M]&*ON?$R`D!&:O$``S2LS?@`L/[WM.Q`1B@B(4;^]SSL*"@JT3-+,D8S22A&
M>T3-Z0!S,4MY1`*4`Y%[1`(AC?CXL/[WYNQZYP>;T_@$D+GQ``\_]":O2$;^
M]T+L`RA_]B"O)DD$.$A$>43^]P3M`"@(O\M&%>?^]X[L(4AX1/_WG/Q*:```
M1&@``'YI```@`0``7A0``#(5``"4%```F!0``((3``!Z%```)`$``(X4``":
M9@``SA,``$@4```@%```G!(``%@4``!R$@``YA,``(P4``#Z$0``$A(``)H4
M``#:$P``BA$``)82``#<9```SA```%83``"($@``1A(``#H2``!D265*>41P
MM5I+@K`=[G!/BEAN1F%(,482:`&23_```GM$&VAX1.58E?AH,(7X:3#^]QS^
M$+$#>#$K?-#_]SSZ34M[1!MHY5A522A&`R,!(GE$_O=RZP5&<+$":4=+>T0;
M:!%H3TK@6'I$_O=RZRMI&6B+:%L":]1!20,C`2)Y1`EH8%A(27E$_O=6ZP5&
M>+%&2#%&>$3^]^G]`D8`*$[0.$LI:7M$&V@):.!8_O=0ZS5+`2(^27M$&VAY
M1.58*$;^]Q;K.TH!1BA&>D0Z3?[W0.LN2SE(?41[1!MH`")X1#%&XUB#^&D@
M_O?`_01&J&"PL4_TX'$@1O[WW.I"'`-&$2@8OP$J+-@M2B-+>D336!IH`9M:
M0$_P``,@T0*P<+UH:/_W\?P$1JA@`"CAT25(>$3^]\[K0W@`*X70?N<B2RII
M>T00:%MH&6C^]T/_K^</2WM$&VC@6/[WB.N,Y_[WF.L:22)&&DAY1'A$26@)
M:/[WKNM09```+F0``!)D``#R8P``S&,``+IC``"88P``'F,``%QC```@`0``
M_`\``*`1``",$0``=A$``$0/``!&$0``3A$```YD``#N#@``5&(``/`0``"B
M8P``?&,``-H0```I2BI+>D0PM01&*4B#L--8:49X1!MH`9-/\``#_O<\_7"Q
M`W@`*QB_,"L,OP$C`".#\`$#`"P,OP`C`_`!`UNY'$H:2WI$TU@::`&;6D!/
M\``#)]$#L#"](W@`*_#0($;_][KX+R$%1O[WCNH`L44<*$;^]PSK$$D$(GE$
M_O=BZP`HW=$-2@E+>D336!IH`9M:0$_P``,%T2!&`["]Z#!`_O=VO?[W"NN(
M80``(`$``%8.``!(80``L@X```1A```MZ?!/`T;?^!!*K?4K?0/Q@`??^`@Z
M?$0(J0`F`I`*1D`PO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0?",*)0(#
M]']#"#!#ZA1C!?1_!4/J!&-@14/J!0-"^`@\YM'=Z2*""JPFFPWQB`D`DR2H
M)JT!]0)S`Y`@1@25S>D%00UHS?@<D)%&W?B4X-WXG,`)G]WX++`DGMWX**``
MF0&3`>"21IM&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GE5&7$"$Z@D$
M\49\0.9&3^K1?$D83.I$#`&<0>H,`5]&3_``#(1"`6?:T0.;`IC=Z05!'6@$
MF]#I`7L;:`.3T.D#.D_JFP[0^`#`"F@A:$[J@WZ$:4?VF1/%]H(C`)0$:M(8
M3^K<8`&40.I'$!(9`)Q`ZDP0W?@<D((8BNH$`$[JBWX`Z@L`W?@P@&!`V?@`
M8!(83^J<"8KJ#@#)&$GJAWD`Z@P`2>J,>0D9@.H*``Z?"!B.Z@D!&.L#"!%`
M`.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!0$_JL`"!
MZ@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!&.L#"!CK
M`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=
M^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_JL`""Z@X"
M&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#"!CK`0D"
MZ_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^'B`
M"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""Z@X"`YP9
MZP("&.L#"!CK#@X"Z_=H@>H``CI`3^JW!TI`'NL"`O88=AB`Z@<!`>H(`0+K
M^&)!0$_JN`AQ&.T8+1@!Z_)@A^H(`1%`3^JR`HCJ`@9Y0&D8!D`HG>08`>OP
M88;J"`9/ZK``Y!FD&8+J``?M&`]`%>L(!BJ=!.OQ9%=`3^JQ`?89@.H!#NT8
MKQ@.Z@0.+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8-T`M&"Z83T`$Z_9D[QE/
MZK8&PQ@PG5L8@NH&`2%`!^OT;E%`3^JT!%@83O:A,\;VV6,RF17K`P@`Z_Y@
M&.L""(;J!`*"Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/ZK``$NL.
M`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)DCNH"#G49
M3^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\G1[K`0X'
MZ_!A@NH$!T=`3^JP`![K!P[O&#Z>OQ@.Z_%BA.H`#H[J`0Y/ZK$!%^L.!Q;K
M`PY`G1[K!`X'Z_)D@.H!!U=`3^JR`A[K!P[O&$*>/Q@.Z_1@@>H"#H[J!`Y/
MZK0$%^L.!T2=@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.[1@&Z_=F
MCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.!$J9TAB'
MZ@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD93^JT!!'K
M#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ8H[J`0Y]
M&4_JL0$5ZPX%4I_V&(#J`0Z.Z@(.-!D4ZPX$!>OR9A?K`PY/ZK("5)T>ZP`.
M@>H"``3K]F1P0![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT!.L86)V;
M&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J`0X$Z@<%
M3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR`D3J#@0!
MZ@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K]61`&$+J
M!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!BGT_JM`1!
MZ@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"_Q@$Z@`.
M?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW!@7K]V4\
M0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%/!E&Z@4'
MP!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT9@7J`0=/
MZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9TAA5&`?K
M\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\0P7K\66D
M&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8%A@'Z_1@
M0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$!T_JL``^
M0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`1^H.!T_J
ML0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.!=,8&QA!
MZ@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E``.OU8'88
M3^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV9'%`?QA/
MZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A:$!/ZK4%
M/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T0#\93^JV
M!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`3^JU!;\9
MUA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/ZK0$OQG6
M&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_JM06_&=88
M-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT!+\9UAAV
M&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%OQG2&!89
M!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!!F9`3^JT
M!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;)!BZ8`Q*
MR1@`(WMB"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_??T[0"_MF``
M`"`!``#65@``"+6`(/WWXNV?[0Y[`"*"9X#M`'N?[0U[@.T">Y_M#7N`[01[
MG^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!(T5G`````(FKS>\`
M````_MRZF`````!V5#(0`````/#ATL,````````````````MZ?A#!4861H!J
M`",,1O<7U>D,(0#KQ@R$1>AJ<^L```+2`3)!\0`!J&\%\3@(Q>D*PW,/0^K'
M`YL8*V-!ZU=Q:6.`NS\N1=VF\4`)3^J9%G<<!.N'%R%&0T8$\4`.T?@`P!`Q
M4?@,3!`S4?@(#%'X!"QQ14/X$,Q#^`Q,0_@(#$/X!"SKT0Q&*$;_]VWZO$+A
MT:GKAA8R1CE&0$;]]Q+MKF>]Z/B#P/%`!P7Q.`BW0D!$J+\W1B%&.D;]]P3M
MJV\[1*MG0"OLT2A&]AL\1/_W2_JWYR=&WN<MZ?!!`?$X!PQ&BVH%1@IKD_J#
M^,/SQ0,6NED<@"(X*?I41=W!\4`">!@`(?WWB.P@1O_W+?HX1C@B`"']]X#L
M($;$Z1QH__<C^N-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*JW&C
M:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C,"MT
M8XQK="-J&PJK="-JZW2]Z/!!_?=FO'@8P?$X`@`A_?="[,#G`+\"2WM$&VC]
M]_F\`+_650``"$`MZ0B`O>@!``(`/@```$$````,````00```!$```!!````
M)P```$$````V````00````,```!!````!@```$$````5````00````\```!!
M````#@```$$````F````00```!,```!!````*0```$$````"````00```!D`
M``!!````"@```$$````+````00``````````````)7,O)7,````O<')O8R]S
M96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``
M````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@``
M``!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(
M10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!0
M05)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``
M``!L<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(
M`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`%!!5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8
M````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C$`
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!4
M14U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&
M24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`]
M(#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:
M25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE
M+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S
M("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*
M;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O
M=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!
M3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'
M24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E
M860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]
M('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O
M9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,
M15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A
M8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2([
M"B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F
M:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F
M?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N
M92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@
M1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&
M2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U
M="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF
M("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@
M<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F
M:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C
M86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS
M965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@
M,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I
M>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L
M"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B10
M05)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M
M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68[
M"G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R
M;'AS:2YC`````$-!0TA%```^````00````P```!!````$0```$$````G````
M00```#8```!!`````P```$$````&````00```!4```!!````#P```$$````.
M````00```"8```!!````$P```$$````I````00````(```!!````&0```$$`
M```*````00````L```!!``````````````"@FO]_`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````S1<``(T7```!````/0,```$```!-`P```0```%<#```,````
M^!$```T````X.@``&0```+B-```;````!````!H```"\C0``'`````0```#U
M_O]OM`$```4```!`"0``!@```*`"```*````T@0```L````0````%0``````
M```#````R(X```(```#H`0``%````!$````7````$!```!$````X#P``$@``
M`-@````3````"````!X````(````^___;P$```C^__]OZ`X``/___V\"````
M\/__;Q(.``#Z__]O#@``````````````````````````````````````````
M``````````````#`C0`````````````$$@``!!(```02```$$@``!!(```02
M```$$@``!!(```02```$$@``!!(```02```$$@``!!(```02```$$@``!!(`
M``02```$$@``!!(```02```$$@``!!(```02```$$@``!!(```02```$$@``
M!!(```02```$$@``!!(```02```$$@``!!(```02```$$@``!!(```02```$
M$@``!!(```02```$$@``!!(```02```$$@``!!(```02```$$@``!!(```02
M```$$@``!!(```02```$$@``!!(```02```$$@``!!(```02```$$@``````
M````````````````````````````````````````````````````````````
M``````D5````````!)````I005(N<&T*`````!@^```P.P```````/`[``#T
M.P``##X``#@[```4/@```````/@]````/@```````"`^``!'0T,Z("A58G5N
M='4@,3,N,BXP+3$W=6)U;G1U,BD@,3,N,BXP`$$R````865A8FD``2@````%
M-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D
M871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M````````"P````$````"````5`$``%0!```9```````````````!````````
M`!,````'`````@```'`!``!P`0``)```````````````!``````````F````
M!P````(```"4`0``E`$``"````````````````0`````````-````/;__V\"
M````M`$``+0!``#L````!0`````````$````!````#X````+`````@```*`"
M``"@`@``H`8```8````#````!````!````!&`````P````(```!`"0``0`D`
M`-($``````````````$`````````3@```/___V\"````$@X``!(.``#4````
M!0`````````"`````@```%L```#^__]O`@```.@.``#H#@``4`````8````"
M````!`````````!J````"0````(````X#P``.`\``-@````%``````````0`
M```(````<P````D```!"````$!```!`0``#H`0``!0```!4````$````"```
M`'P````!````!@```/@1``#X$0``#```````````````!`````````!W````
M`0````8````$$@``!!(````#``````````````0````$````@@````$````&
M````"!4```@5```P)0`````````````(`````````(@````!````!@```#@Z
M```X.@``"```````````````!`````````".`````0````(```!`.@``0#H`
M`/1!``````````````0`````````E@````$``'""````-'P``#1\```(````
M#0`````````$`````````*$````!`````@```#Q\```\?```!```````````
M````!`````````"K````#@````,```"XC0``N'T```0```````````````0`
M```$````MP````\````#````O(T``+Q]```$```````````````$````!```
M`,,````&`````P```,"-``#`?0``"`$```8`````````!`````@```#,````
M`0````,```#(C@``R'X``#@!``````````````0````$````T0````$````#
M`````)````"```!(```````````````$`````````-<````(`````P```$B0
M``!(@```%```````````````!`````````#<`````0```#``````````2(``
M`"8```````````````$````!````Y0````,``'```````````&Z````S````
M```````````!``````````$````#``````````````"A@```]0``````````
+`````0``````````
